@@ -13,6 +13,7 @@ from django.utils.translation import ugettext_lazy as _
 
 
 from .auth import generate_verify_email_token
+from .validators import validate_gb_phone_number
 from .MailFilter import filtered_send_mail
 
 # remove username from the default django user model. (Creating a custom user model based on the original django model)
@@ -55,14 +56,7 @@ class User(AbstractBaseUser, PermissionsMixin):
     phone_number = models.CharField(
         null=True,
         max_length=20,
-        validators=[
-            RegexValidator(
-                regex=r'^\+?1?\d{9,15}$',
-                message=(_(
-                    "Phone number format must be entered in the format: (+)9999999 with optional international code e.g (+4499999). Between 8 and 15 digits allowed."
-                ))
-            )
-        ]
+        validators=[validate_gb_phone_number]
     )
     profile_pic = models.ImageField(blank=True, null=True)
     is_staff = models.BooleanField(_('staff status'), default=False,
