@@ -359,7 +359,7 @@ class PasswordResetConfirmSerializer(serializers.Serializer):
             raise ValidationError(self.set_password_form.errors)
         if not default_token_generator.check_token(self.user, data['token']):
             raise ValidationError(
-                {'token': ['Expiried or is invalid']})
+                {'token': ['Expired or is invalid']})
 
         return data
 
@@ -367,37 +367,6 @@ class PasswordResetConfirmSerializer(serializers.Serializer):
         return self.set_password_form.save()
 
 
-# class SendEmailVerificationSerializer(serializers.Serializer):
-
-#     user_id = serializers.IntegerField()
-#     email = serializers.EmailField()
-
-#     def save(self):
-
-#         token = generate_verify_email_token(
-#             self.validated_data['user_id'],
-#             self.validated_data['email']
-#         )
-
-#         # TODO red - this is current hard coded, maybe make it dynamic
-#         template_params = {
-#             'user': self.context.get('user'),
-#             'url': f"{settings.SITE_URL}/verify?token={token}"
-#         }
-
-#         msg_plain = render_to_string('verify_email.txt', template_params)
-#         msg_html = render_to_string('verify_email.html', template_params)
-
-#         filtered_send_mail(
-#             'Ripple Energy - Account Verification Email',
-#             msg_plain,
-#             'support@example.com',
-#             [self.validated_data['email']],
-#             html_message=msg_html,
-#             fail_silently=False,
-#         )
-
-
 class ConfirmEmailSerializer(serializers.Serializer):
 
     token = serializers.CharField(max_length=256)
